@@ -35,7 +35,6 @@ pub fn cutout(graph: &Gfa, node: &String, lens: usize) -> (HashSet<String>, Hash
             //println!("{}", "\n");
             //println!("{}", ind);
             if (ind < lens) & ((ind + lens) > x.nodes.iter().len()){
-                println!("{}", 1);
                 maxx = x.nodes.iter().len();
                 min = 0;
             } else if ind < lens{
@@ -118,7 +117,7 @@ fn main() {
 
         if checkUnique(&graph, &args[2]){
             let nu = args[3].parse::<usize>().unwrap();
-            let (u, u2) = cutout(&graph, &"40".to_owned(), nu);
+            let (u, u2) = cutout(&graph, &args[2].to_owned(), nu);
             println!("{}\t{}", "H","VN:Z:1.0");
             sortout(&graph, &u, &u2);
         } else{
